/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.artifact;

import java.util.Collection;

/**
 * A Transferable is a object, wich is transported between the backend and frontend of the system.
 * <ol>
 * <li>It holds a payLoad wich could be writen to different DCPs</li>
 * <li>It holds a set of TransferAttributes, wich describe the special aspects of the payload, or holds other special
 * information for different DCPs</li>
 * </ol>
 *
 */
public interface Transferable {

    Payload getPayload();

    void setPayload(Payload pPayload);

    /**
     * @return the collection of keys, under which TransferAttributes.
     * are stored
     */
    Collection<String> getAttributeNames();

    /**
     * @return the Collection of TransferAttributes which stored in.
     * this Transferable
     *
     */
    Collection<TransferAttribute> getAttributes();

    /**
     * Gets the TransferAttribute which are stored under pName.
     *
     * @param pName
     * @return null <==> (!getAttributeNames.contains(pKey) || pKey==null)
     */
    TransferAttribute getAttribute(String pName);

    /**
     * Gets the value of the TransferAttribute which are stored under pName.
     *
     * @param pName
     * @return null <==> (!getAttributeNames.contains(pName) || pName==null) <br/>
     *         short for getAttribute(pName).getValue();
     */
    Object getAttributeValue(String pName);

    /**
     * Adds an attribute to the set and stores it under pAttribute.getName().
     *
     * @param pAttribute
     *            The Attribute
     */
    void addAttribute(TransferAttribute pAttribute);

    /**
     * Removes an attribute from the transferable.
     *
     * @param name
     *            the attribute name.
     */
    void removeAttribute(String name);
}
