/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.subject;

/**
 * A scope with a name.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public class NamedScope implements Scope {


    private static final long serialVersionUID = 115044619144833705L;

    /**
     * Field m_name contains the name, wich describes the name of this scope.
     */
    private String m_name;
    /**
     * Field m_scope contains the parent scope.
     */
    private Scope m_scope;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new NamedScope with the specified name.
     * <p/>
     * It throws an IllegalArgumentException if one of the arguments are null.
     *
     * @param name the name != null.
     * @throws IllegalArgumentException if the given string is null.
     */
    public NamedScope(final String name) throws IllegalArgumentException {
        this(name, Scope.GLOBAL);
    }

    /**
     * Constructor creates a new NamedScope with the specified name.
     * <p/>
     * It throws an IllegalArgumentException if one of the arguments are null.
     *
     * @param name  the name != null.
     * @param scope the scope != null.
     * @throws IllegalArgumentException if the given string is null.
     */
    public NamedScope(final String name, final Scope scope) throws IllegalArgumentException {
        if (name == null) {
            throw new IllegalArgumentException("the name of a NamedScope must not be null");
        }
        if (scope == null) {
            throw new IllegalArgumentException("the scope of a NamedScope must not be null");
        }
        m_name = name;
        m_scope = scope;
    }

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * Method gets the name of this NamedScope object.
     *
     * @return String.
     * @see Scope#getName()
     */
    public String getName() {
        return m_name;
    }

    /**
     * Method gets the scope of this NamedScope object.
     *
     * @return Scope.
     * @see Scope#getScope()
     */
    public Scope getScope() {
        return m_scope;
    }

    // ------------------------ CANONICAL METHODS ------------------------

    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        final NamedScope namedScope = (NamedScope) o;

        if (!m_scope.equals(namedScope.m_scope)) {
            return false;
        }
        if (!m_name.equals(namedScope.m_name)) {
            return false;
        }

        return true;
    }

    public int hashCode() {
        int result;
        result = m_name.hashCode();
        result = 31 * result + m_scope.hashCode();
        return result;
    }

    public String toString() {
        return getName();
    }
}
