/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.subject;

import java.io.Serializable;

/**
 * Role(-identity) of a user.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 16.09.2007
 * @version $Revision: $
 */
public class RolePrincipal extends NamePrincipal implements Serializable {

    private static final long serialVersionUID = -1423592217263898411L;


    /**
     * Creates a role principal with the given name and valid in the global scope.
     * <p/>
     * It throws an IllegalArgumentException if one of the arguments is null.
     *
     * @param name a role name != null.
     * @throws IllegalArgumentException if one of the arguments is null.
     */
    public RolePrincipal(final String name) throws IllegalArgumentException {
        super(name, Scope.GLOBAL);
    }

    /**
     * Creates a role principal with the given name and valid only for the specified scope.
     * <p/>
     * It throws an IllegalArgumentException if one of the arguments is null.
     *
     * @param name  a role name != null.
     * @param scope the scope of the role != null.
     * @throws IllegalArgumentException if one of the arguments is null.
     */
    public RolePrincipal(final String name, final Scope scope) throws IllegalArgumentException {
        super(name, scope);
    }
}