package org.n52.security.common.util;

/**
 * The timer task definition is used in the {@link TimerTaskScheduler} to define timer tasks.
 */
public class TimerTaskDefinition {
    /**
     * a name only used for debugging purpose.
     */
    private String m_name = "";

    private long m_delay = 0;
    private long m_period = -1;
    private Runnable m_task;

    public TimerTaskDefinition() {}

    public static TimerTaskDefinition create(String name, long delay, long period, Runnable task) {
        if (task == null) {
            throw new IllegalArgumentException("<task> must not be null!");
        }
        TimerTaskDefinition def = new TimerTaskDefinition();
        def.setName(name);
        def.setDelay(delay);
        def.setPeriod(period);
        def.setTask(task);
        return def;
    }

    public static TimerTaskDefinition create(String name, long delayAndPeriod, Runnable task) {
        return create(name, delayAndPeriod, delayAndPeriod, task);
    }

    public long getDelay() {
        return m_delay;
    }

    public void setDelay(long delay) {
        m_delay = delay;
    }

    public long getPeriod() {
        return m_period;
    }

    public void setPeriod(long period) {
        m_period = period;
    }

    public Runnable getTask() {
        return m_task;
    }

    public void setTask(Runnable task) {
        m_task = task;
    }

    public String getName() {
        if (!m_name.isEmpty()) {
            return m_name;
        }
        if (m_task != null) {
            return m_task.toString();
        }
        return "";
    }

    public void setName(String name) {
        m_name = name == null ? "" : name;
    }

    @Override
    public String toString() {
        return "TimerTaskDefinition [name=" + getName() + "]";
    }

}
