/*
 *  Copyright (C) con terra GmbH (http://www.conterra.de)
 *  All rights reserved
 */
package org.n52.security.common.xml;

import javax.xml.stream.XMLResolver;
import javax.xml.stream.XMLStreamException;
import org.xml.sax.InputSource;

public class ClasspathXMLResolver extends ClasspathResourceResolver implements XMLResolver {

    /**
     * Retrieves a resource. This resource can be of the following three return
     * types: (1) java.io.InputStream (2) javax.xml.stream.XMLStreamReader (3)
     * java.xml.stream.XMLEventReader. If this method returns null the processor
     * will attempt to resolve the entity using its default mechanism.
     *
     * @param publicID - The public identifier of the external entity being
     * referenced, or null if none was supplied.
     * @param systemID - The system identifier of the external entity being
     * referenced.
     * @param baseURI - Absolute base URI associated with systemId.
     * @param namespace - The namespace of the entity to resolve.
     * @return
     * @throws XMLStreamException
     */
    @Override
    public Object resolveEntity(
            String publicID,
            String systemID,
            String baseURI,
            String namespace) throws XMLStreamException {
        InputSource resolvedsource = lookupIgnoreQuite(systemID);
        if (resolvedsource == null) {
            resolvedsource = lookupIgnoreQuite(publicID);
        }
        if (resolvedsource == null) {
            resolvedsource = lookup(namespace);
        }
        return resolvedsource.getByteStream();
    }
}
